@@ -1,7 +1,7 @@
 package Complete::Common;
 
 our $DATE = '2015-11-29'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,12 +12,6 @@ our @EXPORT_OK = qw(
                        %arg_word
                        %args_common_opts
                        %args_path_opts
-                       $OPT_CI
-                       $OPT_WORD_MODE
-                       $OPT_FUZZY
-                       $OPT_MAP_CASE
-                       $OPT_EXP_IM_PATH
-                       $OPT_DIG_LEAF
                );
 
 our %EXPORT_TAGS = (
@@ -133,7 +127,7 @@ Complete::Common - Common stuffs for completion routines
 
 =head1 VERSION
 
-This document describes version 0.19 of Complete::Common (from Perl distribution Complete-Common), released on 2015-11-29.
+This document describes version 0.20 of Complete::Common (from Perl distribution Complete-Common), released on 2015-11-29.
 
 =head1 DESCRIPTION
 
